macro_rules! hopper_lazy_entrypoint {
( $process:expr ) => { ... };
}Expand description
Declare the canonical lazy program entrypoint that defers account parsing.
macro_rules! hopper_lazy_entrypoint {
( $process:expr ) => { ... };
}Declare the canonical lazy program entrypoint that defers account parsing.