pub unsafe fn process_entrypoint<const MAX: usize>(
input: *mut u8,
process_instruction: fn(&Address, &[AccountView], &[u8]) -> ProgramResult,
) -> u64Expand description
Process the BPF entrypoint input.
This is the function called by the canonical Hopper Native entrypoint macro’s generated entrypoint.
Safety
input must be the raw pointer provided by the Solana runtime.