pub fn get_return_data() -> Option<ReturnData>Expand description
Retrieve return data from the most recent CPI call.
Returns None if no return data was set (length == 0).
pub fn get_return_data() -> Option<ReturnData>Retrieve return data from the most recent CPI call.
Returns None if no return data was set (length == 0).