Module sysvar

Module sysvar 

Sysvar access via direct syscalls.

Provides zero-alloc, zero-deserialization access to Solana sysvars by reading them directly into stack buffers via syscalls. No framework wraps the epoch schedule sysvar at the native level.

Structs

Clock
Clock sysvar data, read directly from the runtime.
EpochSchedule
Epoch schedule sysvar data.
Rent
Rent sysvar data.

Constants

CLOCK_ID
Clock sysvar address.
EPOCH_SCHEDULE_ID
Epoch schedule sysvar address.
RENT_ID
Rent sysvar address.

Functions

get_clock
Read the Clock sysvar.
get_epoch_schedule
Read the EpochSchedule sysvar.
get_rent
Read the Rent sysvar.